Improve this Doc View Source

Use this directive to force the angular.element library. This should be used to force either jqLite by leaving ng-jq blank or setting the name of the jquery variable under window (eg. jQuery).

Since angular looks for this directive when it is loaded (doesn't wait for the DOMContentLoaded event), it must be placed on an element that comes before the script which loads angular. Also, only the first instance of `ng-jq` will be used and all others ignored.

## Directive Info

- This directive executes at priority level 0.

## Usage

- as element:

      <ng-jq
        [ng-jq="string"]>
      ...
      </ng-jq>

- as attribute:

      <ANY
        [ng-jq="string"]>
      ...
      </ANY>

### Arguments

Param | Type | Details
--- | --- | ---
ngJq (optional) | string | the name of the library available under `window` to be used for angular.element

## Examples

This example shows how to force jqLite using the `ngJq` directive to the `html` tag.

    <!doctype html>
    <html ng-app ng-jq>
    ...
    ...
    </html>

This example shows how to use a jQuery based library of a different name. The library name must be available at the top most 'window'.

    <!doctype html>
    <html ng-app ng-jq="jQueryLib">
    ...
    ...
    </html>